dot-extract_surv_at_t0: Extract survival + SE at a fixed time from a 'survfit'...

.extract_surv_at_t0R Documentation

Extract survival + SE at a fixed time from a survfit object, by arm

Description

Extract survival + SE at a fixed time from a survfit object, by arm

Usage

.extract_surv_at_t0(fit, t0)

Arguments

fit

A survival::survfit object fit on Surv(time, status) ~ A.

t0

Time at which to extract survival estimates.

Value

A list with S0, S1 (survival estimates for A=0/A=1) and se0, se1 (their standard errors).


sbwadjust documentation built on Oct. 10, 2026, 5:08 p.m.